#!/bin/sh
#
# rc.be_functions.sh
#
# part of pfSense Plus (https://www.netgate.com)
# Copyright (c) 2022 Rubicon Communications, LLC (Netgate)
# All rights reserved.
#

# set a zfs property
_be_zfs_set_property() {
	local _target="${1}"
	local _property="${2}"
	local _value="${3}"

	/sbin/zfs set "${_property}=${_value}" "${_target}" 1>/dev/null 2>&1
}

# wrapper for pkg(8)
_be_pkg() {
	/usr/local/sbin/pkg-static "$@" 2>/dev/null
}

# returns the base package version
_be_get_pkg_version() {
	_ver="$( _be_pkg query %v "${product_name}-base" | /usr/bin/head -n1 )"
	if [ $? -eq 0 ]; then
		echo ${_ver}
		return 0
	fi
	echo "unknown"
	return 1
}

# returns the current root filesystem
_be_get_rootfs() {
	/sbin/mount | /usr/bin/awk '/ \/ / {print $1}'
}

# determine if root filesystem is on zfs
_be_is_root_on_zfs() {
	_be_get_rootfs | grep -qv -m 1 -E "^/dev/"
}

#
# syncs useful zfs user properties from the current root
#
# notes:
#     pfsense:lastsync records the last time we ran synced properties
#     pfsense:upgrading is set when we are performing an upgrade
#     pfsense:version records the base system version
#
be_sync_zfs_properties() {
	if !(_be_is_root_on_zfs); then
		return 1
	fi

	local _ds_name="$( _be_get_rootfs )"

	_be_zfs_set_property "${_ds_name}" pfsense:lastbooted "$( date "+%s" )"
	_be_zfs_set_property "${_ds_name}" pfsense:upgrading "-"
	_be_zfs_set_property "${_ds_name}" pfsense:version "$( _be_get_pkg_version )"
}
